==> vue-year-range-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-range/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import Clickoutside from '@opentinyvue/vue-renderless/common/deps/clickoutside';
import YearTable from '@opentinyvue/vue-year-table';
import { IconDoubleRight, IconDoubleLeft } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    Clickoutside
  }),
  components: {
    YearTable,
    IconDoubleRight: IconDoubleRight(),
    IconDoubleLeft: IconDoubleLeft()
  },
  props: [].concat(props, ["emitter"]),
  emits: ["dodestroy", "pick"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "w-[552px] text-color-text-primary text-xs shadow-md bg-color-bg-1 rounded leading-4 my-0.5 mx-0",
    class: [{
      "w-[664px]": _vm.slots.sidebar || _vm.state.shortcuts
    }, _vm.state.popperClass]
  }, [_c("div", {
    staticClass: "after:content-[''] after:table after:clear-both"
  }, [_vm._t("sidebar"), _vm.state.shortcuts ? _c("div", {
    staticClass: "absolute top-0 bottom-0 w-28 border-r border-r-color-bg-3 box-border pt-5 bg-color-bg-1 overflow-auto"
  }, _vm._l(_vm.state.shortcuts, function(shortcut, key) {
    return _c("button", {
      key,
      staticClass: "block w-24 my-0 mx-auto rounded border-0 bg-transparent leading-8 text-xs text-color-text-primary pl-4 text-left outline-0 cursor-pointer truncate hover:bg-color-bg-2",
      attrs: {
        "type": "button",
        "title": shortcut.text
      },
      on: {
        "click": function click($event) {
          return _vm.handleShortcutClick(shortcut);
        }
      }
    }, [_vm._v(" " + _vm._s(shortcut.text) + " ")]);
  }), 0) : _vm._e(), _c("div", {
    staticClass: "after:content-[''] after:table after:clear-both min-w-[513px]",
    class: {
      "ml-28": _vm.slots.sidebar || _vm.state.shortcuts
    }
  }, [_c("div", {
    staticClass: "m-0 float-left w-1/2 border-r border-r-color-bg-3 relative py-0 px-4"
  }, [_c("div", {
    staticClass: "relative text-center h-12 p-4"
  }, [_c("button", {
    staticClass: "float-left text-sm leading-4 fill-color-text-primary border-0 bg-left-bottom cursor-pointer outline-0 hover:fill-color-brand",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("div", {
    staticClass: "mx-12 text-xs font-medium"
  }, [_vm._v(_vm._s(_vm.state.leftLabel))])]), _c("year-table", {
    ref: "leftYearTable",
    attrs: {
      "selection-mode": _vm.state.selectionMode,
      "date": _vm.state.leftDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "start-year": _vm.state.leftStartYear
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1), _c("div", {
    staticClass: "m-0 float-right w-1/2 border-r border-r-color-bg-3 relative py-0 px-4"
  }, [_c("div", {
    staticClass: "relative text-center h-12 p-4"
  }, [_c("button", {
    staticClass: "float-right text-sm leading-4 fill-color-text-primary border-0 bg-left-bottom cursor-pointer outline-0 hover:fill-color-brand",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextYear
    }
  }, [_c("icon-double-right")], 1), _c("div", {
    staticClass: "mx-12 text-xs font-medium"
  }, [_vm._v(_vm._s(_vm.state.rightLabel))])]), _c("year-table", {
    ref: "rightRearTable",
    attrs: {
      "selection-mode": _vm.state.selectionMode,
      "date": _vm.state.rightDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "start-year": _vm.state.rightStartYear
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)])], 2)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-year-range-2.22.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-range/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import { Clickoutside } from '@opentinyvue/vue-directive';
import YearTable from '@opentinyvue/vue-year-table';
import { IconDoubleRight, IconDoubleLeft } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    Clickoutside
  }),
  components: {
    YearTable,
    IconDoubleRight: IconDoubleRight(),
    IconDoubleLeft: IconDoubleLeft()
  },
  props: [].concat(props, ["emitter"]),
  emits: ["dodestroy", "pick", "select-change", "update:modelValue"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm$state$shortcuts, _vm$state$shortcuts2, _vm$state$shortcuts3;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    on: {
      "after-leave": function afterLeave($event) {
        return _vm.$emit("dodestroy");
      }
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    staticClass: "w-[552px] text-color-text-primary text-xs shadow-md bg-color-bg-1 rounded leading-4 my-0.5 mx-0",
    class: [{
      "w-[664px]": _vm.slots.sidebar || ((_vm$state$shortcuts = _vm.state.shortcuts) === null || _vm$state$shortcuts === void 0 ? void 0 : _vm$state$shortcuts.length)
    }, _vm.state.popperClass]
  }, [_c("div", {
    staticClass: "after:content-[''] after:table after:clear-both"
  }, [_vm._t("sidebar"), (_vm$state$shortcuts2 = _vm.state.shortcuts) !== null && _vm$state$shortcuts2 !== void 0 && _vm$state$shortcuts2.length ? _c("div", {
    staticClass: "absolute top-0 bottom-0 w-28 border-r border-r-color-bg-3 box-border pt-5 bg-color-bg-1 overflow-auto"
  }, _vm._l(_vm.state.shortcuts, function(shortcut, key) {
    return _c("button", {
      key,
      staticClass: "block w-24 my-0 mx-auto rounded border-0 bg-transparent leading-8 text-xs text-color-text-primary pl-4 text-left outline-0 cursor-pointer truncate hover:bg-color-bg-2",
      attrs: {
        "type": "button",
        "title": shortcut.text
      },
      on: {
        "click": function click($event) {
          return _vm.handleShortcutClick(shortcut);
        }
      }
    }, [_vm._v(" " + _vm._s(shortcut.text) + " ")]);
  }), 0) : _vm._e(), _c("div", {
    staticClass: "after:content-[''] after:table after:clear-both min-w-[513px]",
    class: {
      "ml-28": _vm.slots.sidebar || ((_vm$state$shortcuts3 = _vm.state.shortcuts) === null || _vm$state$shortcuts3 === void 0 ? void 0 : _vm$state$shortcuts3.length)
    }
  }, [_c("div", {
    staticClass: "m-0 float-left w-1/2 border-r border-r-color-bg-3 relative py-0 px-4"
  }, [_c("div", {
    staticClass: "relative text-center h-12 p-4"
  }, [_c("button", {
    staticClass: "float-left text-sm leading-4 fill-color-text-primary border-0 bg-left-bottom cursor-pointer outline-0 hover:fill-color-brand",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.leftPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("div", {
    staticClass: "mx-12 text-xs font-medium"
  }, [_vm._v(_vm._s(_vm.state.leftLabel))])]), _c("year-table", {
    ref: "leftYearTable",
    attrs: {
      "selection-mode": _vm.state.selectionMode,
      "date": _vm.state.leftDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "start-year": _vm.state.leftStartYear
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1), _c("div", {
    staticClass: "m-0 float-right w-1/2 border-r border-r-color-bg-3 relative py-0 px-4"
  }, [_c("div", {
    staticClass: "relative text-center h-12 p-4"
  }, [_c("button", {
    staticClass: "float-right text-sm leading-4 fill-color-text-primary border-0 bg-left-bottom cursor-pointer outline-0 hover:fill-color-brand",
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.rightNextYear
    }
  }, [_c("icon-double-right")], 1), _c("div", {
    staticClass: "mx-12 text-xs font-medium"
  }, [_vm._v(_vm._s(_vm.state.rightLabel))])]), _c("year-table", {
    ref: "rightRearTable",
    attrs: {
      "selection-mode": _vm.state.selectionMode,
      "date": _vm.state.rightDate,
      "default-value": _vm.state.defaultValue,
      "min-date": _vm.state.minDate,
      "max-date": _vm.state.maxDate,
      "range-state": _vm.state.rangeState,
      "disabled-date": _vm.state.disabledDate,
      "start-year": _vm.state.rightStartYear
    },
    on: {
      "changerange": _vm.handleChangeRange,
      "pick": _vm.handleRangePick
    }
  })], 1)])], 2)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
